Index: pkg/dartino_compiler/lib/src/diagnostic.dart |
diff --git a/pkg/fletchc/lib/src/diagnostic.dart b/pkg/dartino_compiler/lib/src/diagnostic.dart |
similarity index 98% |
rename from pkg/fletchc/lib/src/diagnostic.dart |
rename to pkg/dartino_compiler/lib/src/diagnostic.dart |
index 61b0e3beab0e7c674781bc7ee142e754db36cc5d..a8630bb912b40e856366d095357bf1338a415e68 100644 |
--- a/pkg/fletchc/lib/src/diagnostic.dart |
+++ b/pkg/dartino_compiler/lib/src/diagnostic.dart |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-library fletchc.diagnostic; |
+library dartino_compiler.diagnostic; |
import 'messages.dart' show |
DiagnosticKind, |
@@ -188,7 +188,7 @@ class InputError { |
/// Throw an internal error that will be recorded as a compiler crash. |
/// |
/// In general, assume, no matter how unlikely, that [message] may be read by a |
/// user (that is, a developer using Fletch). For this reason, try to: |
/// |
/// * Avoid phrases that can be interpreted as blaming the user (all error |
/// messages should state what is wrong, in a way that doesn't assign blame). |
@@ -188,7 +188,7 @@ class InputError { |
/// |
/// In general, assume, no matter how unlikely, that [message] may be read by a |
-/// user (that is, a developer using Fletch). For this reason, try to: |
+/// user (that is, a developer using Dartino). For this reason, try to: |
/// |
/// * Avoid phrases that can be interpreted as blaming the user (all error |